# Generated by Django 3.1.6 on 2021-02-10 13:22

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('contractor', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='contract',
            name='webhook_active',
            field=models.BooleanField(default=False),
        ),
    ]
